#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
#include <map>
#include <unordered_set>
#include <unordered_map>
#include <cmath>
#include <string>

using namespace std;

typedef long long int ll;
typedef long double ld;

struct SegTree{
    vector<ll> tree, mod;

    void init(ll n){
        tree.resize(4 * n);
        mod.resize(4 * n);
    }

    void build(ll v, ll l, ll r, const vector<ll> &a){
        if(r - l == 1){
            tree[v] = a[l];
            mod[v] = 0;
        }else{
            ll m = (l + r) / 2;
            build(2 * v, l, m, a);
            build(2 * v + 1, m, r, a);
            tree[v] = tree[2 * v] + tree[2 * v + 1];
        }
    }

    void push(ll v, ll l, ll r){
        if(r - l == 1){
            mod[v] = 0;
        }
        if(mod[v] == 0){
            return ;
        }
        ll m = (l + r) / 2;
        mod[2 * v] += mod[v];
        mod[2 * v + 1] += mod[v];
        tree[2 * v] += mod[v] * (m - l);
        tree[2 * v + 1] += mod[v] * (r - m);
        mod[v] = 0;
    }

    void add(ll v, ll l, ll r, ll ql, ll qr, ll val){
        if(r <= ql || qr <= l){
            return ;
        }
        push(v, l, r);
        if(ql <= l && r <= qr){
            tree[v] += val * (r - l);
            mod[v] = val;
            return ;
        }
        ll m = (l + r) / 2;
        add(2 * v, l, m, ql, qr, val);
        add(2 * v + 1, m, r, ql, qr, val);
        tree[v] = tree[2 * v] + tree[2 * v + 1];
    }

    ll get(ll v, ll l, ll r, ll ql, ll qr){
        if(r <= ql || qr <= l){
            return 0;
        }
        push(v, l, r);
        if(ql <= l && r <= qr){
            return tree[v];
        }
        ll m = (l + r) / 2;
        return get(2 * v, l, m, ql, qr) + get(2 * v + 1, m, r, ql, qr);
    }

};

int main(){
    ios::sync_with_stdio(false);cin.tie(NULL);cout.tie(NULL);
    ll n, m, q, i, ans, l, r;
    cin >> n >> m >> q;
    SegTree t;
    t.init(m);
    for(i = 0; i < q; i++){
        cin >> l >> r;
        l -= 1;
        r -= 1;
        if((l / m) != (r / m)){
            //cout << l % m << " " << m << " ---\n";
            t.add(1, 0, m, l % m, m, 1);
            t.add(1, 0, m, 0, (r % m) + 1, 1);
            r -= (r % m);
            l += (m - (l % m));
            t.add(1, 0, m, 0, m, (r - l) / m);
        }else{
            t.add(1, 0, m, l % m, (r % m) + 1, 1);
        }
    }
    ans = n;
    //for(i = 0; i < m; i++){
    //    cout << t.get(1, 0, m, i, i + 1) << " ";
    //}cout << "\n";
    for(i = 0; i < m; i++){
        ans = min(ans, t.get(1, 0, m, i, i + 1));
    }
    cout << ans;
    return 0;
}
